@@ -57,9 +57,9 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
         self.totem = totem
 
         self.null_metadata = {
-            'year' : u'', 'tracknumber' : '', 'location' : '',
-            'title' : u'', 'album' : u'', 'time' : u'', 'genre' : u'',
-            'artist' : u''
+            'year' : '', 'tracknumber' : '', 'location' : '',
+            'title' : '', 'album' : '', 'time' : '', 'genre' : '',
+            'artist' : ''
         }
         self.current_metadata = self.null_metadata.copy ()
         self.current_position = 0
@@ -94,7 +94,7 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
             'mpris:trackid': dbus.String (self.totem.props.current_mrl,
                 variant_level = 1),
             'mpris:length': dbus.Int64 (
-                self.totem.props.stream_length * 1000L,
+                self.totem.props.stream_length * 1000,
                 variant_level = 1),
         }
 
@@ -116,26 +116,26 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
 
         return metadata
 
-    def __do_update_metadata (self, totem, artist, # pylint: disable-msg=R0913
+    def __do_update_metadata (self, _, artist, # pylint: disable-msg=R0913
                               title, album, num):
         self.current_metadata = self.null_metadata.copy ()
         if title:
-            self.current_metadata['title'] = unicode (title, 'utf-8')
+            self.current_metadata['title'] = title
         if artist:
-            self.current_metadata['artist'] = unicode (artist, 'utf-8')
+            self.current_metadata['artist'] = artist
         if album:
-            self.current_metadata['album'] = unicode (album, 'utf-8')
+            self.current_metadata['album'] = album
         if num:
             self.current_metadata['tracknumber'] = num
 
         self.PropertiesChanged ('org.mpris.MediaPlayer2.Player',
             { 'Metadata': self.__calculate_metadata () }, [])
 
-    def __do_notify_playing (self, totem, prop):
+    def __do_notify_playing (self, _, prop): # pylint: disable-msg=W0613
         self.PropertiesChanged ('org.mpris.MediaPlayer2.Player',
             { 'PlaybackStatus': self.__calculate_playback_status () }, [])
 
-    def __do_notify_current_mrl (self, totem, prop):
+    def __do_notify_current_mrl (self, _, prop): # pylint: disable-msg=W0613
         self.PropertiesChanged ('org.mpris.MediaPlayer2.Player', {
             'CanPlay': (self.totem.props.current_mrl != None),
             'CanPause': (self.totem.props.current_mrl != None),
@@ -143,16 +143,16 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
                         self.totem.props.seekable),
         }, [])
 
-    def __do_notify_seekable (self, totem, prop):
+    def __do_notify_seekable (self, _, prop): # pylint: disable-msg=W0613
         self.PropertiesChanged ('org.mpris.MediaPlayer2.Player', {
             'CanSeek': (self.totem.props.current_mrl != None and
                         self.totem.props.seekable),
         }, [])
 
-    def __do_notify_current_time (self, totem, prop):
+    def __do_notify_current_time (self, totem, _):
         # Only notify of seeks if we've skipped more than 3 seconds
         if abs (totem.props.current_time - self.current_position) > 3:
-            self.Seeked (totem.props.current_time * 1000L)
+            self.Seeked (totem.props.current_time * 1000)
 
         self.current_position = totem.props.current_time
 
@@ -160,19 +160,19 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
     @dbus.service.method (dbus_interface = dbus.PROPERTIES_IFACE,
                           in_signature = 'ss', # pylint: disable-msg=C0103
                           out_signature = 'v')
-    def Get (self, interface_name, property_name):
+    def Get (self, interface_name, property_name): # pylint: disable-msg=C0103
         return self.GetAll (interface_name)[property_name]
 
     @dbus.service.method (dbus_interface = dbus.PROPERTIES_IFACE,
                           in_signature = 's', # pylint: disable-msg=C0103
                           out_signature = 'a{sv}')
-    def GetAll (self, interface_name):
+    def GetAll (self, interface_name): # pylint: disable-msg=C0103
         if interface_name == 'org.mpris.MediaPlayer2':
             return {
                 'CanQuit': True,
                 'CanRaise': True,
                 'HasTrackList': False,
-                'Identity': self.totem.get_version (),
+                'Identity': 'Videos',
                 'DesktopEntry': 'totem',
                 'SupportedUriSchemes': self.totem.get_supported_uri_schemes (),
                 'SupportedMimeTypes': self.totem.get_supported_content_types (),
@@ -185,20 +185,15 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
             else:
                 loop_status = 'None'
 
-            # Shuffle
-            shuffle = self.totem.action_remote_get_setting (
-                Totem.RemoteSetting.SHUFFLE)
-
             return {
                 'PlaybackStatus': self.__calculate_playback_status (),
                 'LoopStatus': loop_status, # TODO: Notifications
                 'Rate': 1.0,
                 'MinimumRate': 1.0,
                 'MaximumRate': 1.0,
-                'Shuffle': shuffle, # TODO: Notifications
                 'Metadata': self.__calculate_metadata (),
                 'Volume': self.totem.get_volume (), # TODO: Notifications
-                'Position': self.totem.props.current_time * 1000L,
+                'Position': self.totem.props.current_time * 1000,
                 'CanGoNext': True, # TODO
                 'CanGoPrevious': True, # TODO
                 'CanPlay': (self.totem.props.current_mrl != None),
@@ -210,16 +205,17 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
 
         raise dbus.exceptions.DBusException (
             'org.mpris.MediaPlayer2.UnknownInterface',
-            _(u'The MediaPlayer2 object does not implement the ‘%s’ interface')
+            _('The MediaPlayer2 object does not implement the ‘%s’ interface')
                 % interface_name)
 
     @dbus.service.method (dbus_interface = dbus.PROPERTIES_IFACE,
                           in_signature = 'ssv') # pylint: disable-msg=C0103
-    def Set (self, interface_name, property_name, new_value):
+    def Set (self, interface_name, property_name, # pylint: disable-msg=C0103
+             new_value):
         if interface_name == 'org.mpris.MediaPlayer2':
             raise dbus.exceptions.DBusException (
                 'org.mpris.MediaPlayer2.ReadOnlyProperty',
-                _(u'The property ‘%s’ is not writeable.'))
+                _('The property ‘%s’ is not writeable.'))
         elif interface_name == 'org.mpris.MediaPlayer2.Player':
             if property_name == 'LoopStatus':
                 self.totem.action_remote_set_setting (
@@ -227,47 +223,44 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
             elif property_name == 'Rate':
                 # Ignore, since we don't support setting the rate
                 pass
-            elif property_name == 'Shuffle':
-                self.totem.action_remote_set_setting (
-                    Totem.RemoteSetting.SHUFFLE, new_value)
             elif property_name == 'Volume':
                 self.totem.action_volume (new_value)
 
             raise dbus.exceptions.DBusException (
                 'org.mpris.MediaPlayer2.ReadOnlyProperty',
-                _(u'Unknown property ‘%s’ requested of a MediaPlayer 2 object')
+                _('Unknown property ‘%s’ requested of a MediaPlayer 2 object')
                     % interface_name)
 
         raise dbus.exceptions.DBusException (
             'org.mpris.MediaPlayer2.UnknownInterface',
-            _(u'The MediaPlayer2 object does not implement the ‘%s’ interface')
+            _('The MediaPlayer2 object does not implement the ‘%s’ interface')
                 % interface_name)
 
     @dbus.service.signal (dbus_interface = dbus.PROPERTIES_IFACE,
                           signature = 'sa{sv}as') # pylint: disable-msg=C0103
-    def PropertiesChanged (self, interface_name, changed_properties,
-                           invalidated_properties):
+    def PropertiesChanged (self, interface_name,  # pylint: disable-msg=C0103
+                           changed_properties, invalidated_properties):
         pass
 
     # org.mpris.MediaPlayer2 interface
     @dbus.service.method (dbus_interface = 'org.mpris.MediaPlayer2',
                           in_signature = '', # pylint: disable-msg=C0103
                           out_signature = '')
-    def Raise (self):
+    def Raise (self): # pylint: disable-msg=C0103
         main_window = self.totem.get_main_window ()
         main_window.present ()
 
     @dbus.service.method (dbus_interface = 'org.mpris.MediaPlayer2',
                           in_signature = '', # pylint: disable-msg=C0103
                           out_signature = '')
-    def Quit (self):
+    def Quit (self): # pylint: disable-msg=C0103
         self.totem.action_exit ()
 
     # org.mpris.MediaPlayer2.Player interface
     @dbus.service.method (dbus_interface = 'org.mpris.MediaPlayer2.Player',
                           in_signature = '', # pylint: disable-msg=C0103
                           out_signature = '')
-    def Next (self):
+    def Next (self): # pylint: disable-msg=C0103
         if self.totem.is_playing () or self.totem.is_paused ():
             return
 
@@ -276,7 +269,7 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
     @dbus.service.method (dbus_interface = 'org.mpris.MediaPlayer2.Player',
                           in_signature = '', # pylint: disable-msg=C0103
                           out_signature = '')
-    def Previous (self):
+    def Previous (self): # pylint: disable-msg=C0103
         if self.totem.is_playing () or self.totem.is_paused ():
             return
 
@@ -285,25 +278,25 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
     @dbus.service.method (dbus_interface = 'org.mpris.MediaPlayer2.Player',
                           in_signature = '', # pylint: disable-msg=C0103
                           out_signature = '')
-    def Pause (self):
+    def Pause (self): # pylint: disable-msg=C0103
         self.totem.action_pause ()
 
     @dbus.service.method (dbus_interface = 'org.mpris.MediaPlayer2.Player',
                           in_signature = '', # pylint: disable-msg=C0103
                           out_signature = '')
-    def PlayPause (self):
+    def PlayPause (self): # pylint: disable-msg=C0103
         self.totem.action_play_pause ()
 
     @dbus.service.method (dbus_interface = 'org.mpris.MediaPlayer2.Player',
                           in_signature = '', # pylint: disable-msg=C0103
                           out_signature = '')
-    def Stop (self):
+    def Stop (self): # pylint: disable-msg=C0103
         self.totem.action_stop ()
 
     @dbus.service.method (dbus_interface = 'org.mpris.MediaPlayer2.Player',
                           in_signature = '', # pylint: disable-msg=C0103
                           out_signature = '')
-    def Play (self):
+    def Play (self): # pylint: disable-msg=C0103
         # If playing or no track loaded: do nothing,
         # else: start playing.
         if self.totem.is_playing () or self.totem.props.current_mrl == None:
@@ -314,14 +307,14 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
     @dbus.service.method (dbus_interface = 'org.mpris.MediaPlayer2.Player',
                           in_signature = 'x', # pylint: disable-msg=C0103
                           out_signature = '')
-    def Seek (self, offset):
-        self.totem.action_seek_relative (offset / 1000L, False)
+    def Seek (self, offset): # pylint: disable-msg=C0103
+        self.totem.action_seek_relative (offset / 1000, False)
 
     @dbus.service.method (dbus_interface = 'org.mpris.MediaPlayer2.Player',
                           in_signature = 'ox', # pylint: disable-msg=C0103
                           out_signature = '')
-    def SetPosition (self, track_id, position):
-        position = position / 1000L
+    def SetPosition (self, _, position): # pylint: disable-msg=C0103
+        position = position / 1000
 
         # Bail if the position is not in the permitted range
         if position < 0 or position > self.totem.props.stream_length:
@@ -332,15 +325,10 @@ class Root (dbus.service.Object): # pylint: disable-msg=R0923,R0904
     @dbus.service.method (dbus_interface = 'org.mpris.MediaPlayer2.Player',
                           in_signature = 's', # pylint: disable-msg=C0103
                           out_signature = '')
-    def OpenUri (self, uri):
-        if self.totem.action_set_mrl (uri):
-            self.totem.action_play ()
-
-        raise dbus.exceptions.DBusException (
-            'org.mpris.MediaPlayer2.InvalidUri',
-            _(u'The URI ‘%s’ is not supported.') % uri)
+    def OpenUri (self, uri): # pylint: disable-msg=C0103
+        self.totem.add_to_playlist_and_play (uri)
 
     @dbus.service.signal (dbus_interface = 'org.mpris.MediaPlayer2.Player',
                           signature = 'x') # pylint: disable-msg=C0103
-    def Seeked (self, position):
+    def Seeked (self, position): # pylint: disable-msg=C0103
         pass
