@@ -37,6 +37,7 @@ LANGUAGES_STR = [ (D_('iso_639_3', 'Albanian'), 'sq'),
          (D_('iso_639_3', 'Arabic'), 'ar'),
          (D_('iso_639_3', 'Armenian'), 'hy'),
          (D_('iso_639_3', 'Neo-Aramaic, Assyrian'), 'ay'),
+         (D_('iso_639_3', 'Basque'), 'eu'),
          (D_('iso_639_3', 'Bosnian'), 'bs'),
          (_('Brazilian Portuguese'), 'pb'),
          (D_('iso_639_3', 'Bulgarian'), 'bg'),
@@ -102,6 +103,7 @@ LANGUAGES = {'sq':'alb',
          'nl':'dut',
          'en':'eng',
          'eo':'epo',
+         'eu':'eus',
          'et':'est',
          'fi':'fin',
          'fr':'fre',
@@ -252,7 +254,7 @@ class OpenSubtitlesModel (object):
             import locale
             (language_code, _) = locale.getlocale ()
             self.lang = LANGUAGES[language_code.split ('_')[0]]
-        except (ImportError, IndexError, AttributeError):
+        except (ImportError, IndexError, AttributeError, KeyError):
             self.lang = 'eng'
 
         self._lock = threading.Lock ()
@@ -643,7 +645,7 @@ class OpenSubtitles (GObject.Object, # pylint: disable-msg=R0902
 
             flags = Gio.FileCreateFlags.REPLACE_DESTINATION
             try:
-                subtitle_file = Gio.file_new_for_path (self._movie_dir() + sep + movie_name + '.' + ext)
+                subtitle_file = Gio.file_new_for_path (self._movie_dir() + sep + movie_name + '.' + extension)
                 print ('trying to save to ' + subtitle_file.get_uri())
                 suburi = subtitle_file.get_uri ()
 
@@ -651,7 +653,7 @@ class OpenSubtitles (GObject.Object, # pylint: disable-msg=R0902
                 sub_file.write (subtitles, None)
                 sub_file.close (None)
             except:
-                subtitle_file = Gio.file_new_for_path (self._cache_subtitles_dir() + sep + movie_name + '.' + ext)
+                subtitle_file = Gio.file_new_for_path (self._cache_subtitles_dir() + sep + movie_name + '.' + extension)
                 print ('saving to ' + subtitle_file.get_uri())
                 suburi = subtitle_file.get_uri ()
 
